import { Selection, ZoomBehavior } from 'd3'
import { Rect, XYPosition } from './flow'
export declare type D3Zoom = ZoomBehavior<HTMLDivElement, unknown>
export declare type D3Selection = Selection<HTMLDivElement, unknown, any, any>
export declare type D3ZoomHandler = (this: HTMLDivElement, event: any, d: unknown) => void
/** Transform x, y, z */
export declare type Viewport = {
  x: number
  y: number
  zoom: number
}
export declare type KeyCode = number | string
export declare enum PanOnScrollMode {
  Free = 'free',
  Vertical = 'vertical',
  Horizontal = 'horizontal',
}
export declare type ViewportFuncsOptions = {
  duration?: number
}
export declare type FitViewParams = {
  padding?: number
  includeHiddenNodes?: boolean
  minZoom?: number
  maxZoom?: number
  offset?: {
    x?: number
    y?: number
  }
  nodes?: string[]
} & ViewportFuncsOptions
export declare type FlowTransform = {
  x: number
  y: number
  zoom: number
}
export declare type SetCenterOptions = ViewportFuncsOptions & {
  zoom?: number
}
export declare type FitBoundsOptions = ViewportFuncsOptions & {
  padding?: number
}
export declare type FitView = (fitViewOptions?: FitViewParams) => void
export declare type Project = (position: XYPosition) => XYPosition
export declare type SetCenter = (x: number, y: number, options?: SetCenterOptions) => void
export declare type FitBounds = (bounds: Rect, options?: FitBoundsOptions) => void
export declare type ZoomInOut = (options?: ViewportFuncsOptions) => void
export declare type ZoomTo = (zoomLevel: number, options?: ViewportFuncsOptions) => void
export declare type GetTransform = () => FlowTransform
export declare type SetTransform = (transform: FlowTransform, options?: ViewportFuncsOptions) => void
export interface ViewportFuncs {
  zoomIn: ZoomInOut
  zoomOut: ZoomInOut
  zoomTo: ZoomTo
  setTransform: SetTransform
  getTransform: GetTransform
  fitView: FitView
  setCenter: SetCenter
  fitBounds: FitBounds
  project: Project
}
